Description Usage Arguments Details
View source: R/generate_schedules.R
Generate a single schedule
1 2 3 4 5 6 7 | generate_schedule(
league_size = .get_league_size(),
seed = NULL,
seed_init = NULL,
retries = league_size^3,
retries_init = retries
)
|
league_size |
Number of teams in the league. Can be set globally
in the options. See |
seed |
Seed to use |
seed_init |
Initial seed to use, passed to the non-exported |
retries |
Number of retries for a single schedule |
retries_init |
Initial number of retries, passed to the non-exported |
Iterate by week and team, always checking for other matched teams in the same week and previously played teams in prior weeks
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.